@@ -51,33 +51,58 @@
 #'   models remain untransformed. Use \code{NULL} if you want the raw,
 #'   non-transformed estimates.
 #' @param terms Character vector with the names of those terms from \code{model}
-#'   that should be plotted. This argument depends on the plot-type: \describe{
-#'   \item{\emph{Coefficients}}{ Select terms that should be plotted. All other
-#'   term are removed from the output. } \item{\emph{Marginal Effects}}{ Here
-#'   \code{terms} indicates for which terms marginal effects should be
-#'   displayed. At least one term is required to calculate effects, maximum
-#'   length is three terms, where the second and third term indicate the groups,
-#'   i.e. predictions of first term are grouped by the levels of the second (and
-#'   third) term. \code{terms} may also indicate higher order terms (e.g.
-#'   interaction terms). Indicating levels in square brackets allows for
-#'   selecting only specific groups. Term name and levels in brackets must be
-#'   separated by a whitespace character, e.g. \code{terms = c("age", "education
-#'   [1,3]")}. For more details, see \code{\link[ggeffects]{ggpredict}}. } }
+#'   that should be plotted. This argument depends on the plot-type:
+#'   \describe{
+#'     \item{\emph{Coefficients}}{Select terms that should be plotted. All other
+#'       term are removed from the output. Note that the term names must match
+#'       the names of the model's coefficients. For factors, this means that
+#'       the variable name is suffixed with the related factor level, and each
+#'       category counts as one term. E.g. \code{rm.terms = "t_name [2,3]"}
+#'       would remove the terms \code{"t_name2"} and \code{"t_name3"} (assuming
+#'       that the variable \code{t_name} is categorical and has at least
+#'       the factor levels \code{2} and \code{3}). Another example for the
+#'       \emph{iris}-dataset: \code{terms = "Species"} would not work, instead
+#'       you would write \code{terms = "Species [versicolor,virginica]"} to
+#'       remove these two levels, or \code{terms = "Speciesversicolor"} if you
+#'       just want to remove the level \emph{versicolor} from the plot.}
+#'     \item{\emph{Marginal Effects}}{Here \code{terms} indicates for which
+#'       terms marginal effects should be displayed. At least one term is
+#'       required to calculate effects, maximum length is three terms, where
+#'       the second and third term indicate the groups, i.e. predictions of
+#'       first term are grouped by the levels of the second (and third) term.
+#'       \code{terms} may also indicate higher order terms (e.g. interaction
+#'       terms). Indicating levels in square brackets allows for selecting only
+#'       specific groups. Term name and levels in brackets must be separated by
+#'       a whitespace character, e.g. \code{terms = c("age", "education [1,3]")}.
+#'       It is also possible to specify a range of numeric values for the
+#'       predictions with a colon, for instance \code{terms = c("education [1,3]",
+#'       "age [30:50]")}. Furthermore, it is possible to specify a function name.
+#'       Values for predictions will then be transformed, e.g.
+#'       \code{terms = "income [exp]"}. This is useful when model predictors were
+#'       transformed for fitting the model and should be back-transformed to the
+#'       original scale for predictions. Finally, using \code{pretty} for numeric
+#'       variables (e.g. \code{terms = "age [pretty]"}) calculates a pretty range
+#'       of values for the term, roughly of proportional length to the term's
+#'       value range. For more details, see \code{\link[ggeffects]{ggpredict}}.}
+#'  }
 #' @param sort.est Determines in which way estimates are sorted in the plot:
-#'   \itemize{ \item If \code{NULL} (default), no sorting is done and estimates
-#'   are sorted in the same order as they appear in the model formula. \item If
-#'   \code{TRUE}, estimates are sorted in descending order, with highedt
-#'   estimate at the top. \item If \code{sort.est = "sort.all"}, estimates are
-#'   re-sorted for each coefficient (only applies if \code{type = "re"} and
-#'   \code{grid = FALSE}), i.e. the estimates of the random effects for each
-#'   predictor are sorted and plotted to an own plot. \item If \code{type =
-#'   "re"}, specify a predictor's / coefficient's name to sort estimates
-#'   according to this random effect. }
+#'   \itemize{
+#'     \item If \code{NULL} (default), no sorting is done and estimates are sorted in the same order as they appear in the model formula.
+#'     \item If \code{TRUE}, estimates are sorted in descending order, with highest estimate at the top.
+#'     \item If \code{sort.est = "sort.all"}, estimates are re-sorted for each coefficient (only applies if \code{type = "re"} and \code{grid = FALSE}), i.e. the estimates of the random effects for each predictor are sorted and plotted to an own plot.
+#'     \item If \code{type = "re"}, specify a predictor's / coefficient's name to sort estimates according to this random effect.
+#'   }
 #' @param rm.terms Character vector with names that indicate which terms should
 #'   be removed from the plot. Counterpart to \code{terms}. \code{rm.terms =
 #'   "t_name"} would remove the term \emph{t_name}. Default is \code{NULL}, i.e.
-#'   all terms are used. Note that this argument does not apply to
-#'   \emph{Marginal Effects} plots.
+#'   all terms are used. For factors, levels that should be removed from the plot
+#'   need to be explicitely indicated in square brackets, and match the model's
+#'   coefficient names, e.g. \code{rm.terms = "t_name [2,3]"} would remove the terms
+#'   \code{"t_name2"} and \code{"t_name3"} (assuming that the variable \code{t_name}
+#'   was categorical and has at least the factor levels \code{2} and \code{3}).
+#'   Another example for the \emph{iris} dataset would be
+#'   \code{rm.terms = "Species [versicolor,virginica]"}. Note that the
+#'   \code{rm.terms}-argument does not apply to \emph{Marginal Effects} plots.
 #' @param group.terms Numeric vector with group indices, to group coefficients.
 #'   Each group of coefficients gets its own color (see 'Examples').
 #' @param order.terms Numeric vector, indicating in which order the coefficients
@@ -86,7 +111,8 @@
 #' @param pred.type Character, only applies for \emph{Marginal Effects} plots
 #'   with mixed effects models. Indicates whether predicted values should be
 #'   conditioned on random effects (\code{pred.type = "re"}) or fixed effects
-#'   only (\code{pred.type = "fe"}, the default).
+#'   only (\code{pred.type = "fe"}, the default). For details, see documentation
+#'   of the \code{type}-argument in \code{\link[ggeffects]{ggpredict}}.
 #' @param mdrt.values Indicates which values of the moderator variable should be
 #'   used when plotting interaction terms (i.e. \code{type = "int"}). \describe{
 #'   \item{\code{"minmax"}}{(default) minimum and maximum values (lower and
@@ -127,13 +153,22 @@
 #'   axis labels. By default, \code{\link[sjlabelled]{get_term_labels}} is
 #'   called to retrieve the labels of the coefficients, which will be used as
 #'   axis labels. Use \code{axis.labels = ""} or \code{auto.label = FALSE} to
-#'   use the variable names as labels instead.
+#'   use the variable names as labels instead. If \code{axis.labels} is a named
+#'   vector, axis labels (by default, the names of the model's coefficients)
+#'   will be matched with the names of \code{axis.label}. This ensures that
+#'   labels always match the related axis value, no matter in which way
+#'   axis labels are sorted.
 #' @param axis.lim Numeric vector of length 2, defining the range of the plot
 #'   axis. Depending on plot-type, may effect either x- or y-axis. For
 #'   \emph{Marginal Effects} plots, \code{axis.lim} may also be a list of two
 #'   vectors of length 2, defining axis limits for both the x and y axis.
-#' @param grid.breaks Numeric; sets the distance between breaks for the axis,
-#'   i.e. at every \code{grid.breaks}'th position a major grid is plotted.
+#' @param legend.title Character vector, used as legend title for plots that
+#'   have a legend.
+#' @param grid.breaks Numeric value or vector; if \code{grid.breaks} is a
+#'   single value, sets the distance between breaks for the axis at every
+#'   \code{grid.breaks}'th position, where a major grid line is plotted. If
+#'   \code{grid.breaks} is a vector, values will be used to define the
+#'   axis positions of the major grid lines.
 #' @param ci.lvl Numeric, the level of the confidence intervals (error bars).
 #'   Use \code{ci.lvl = NA} to remove error bars. For \code{stanreg}-models,
 #'   \code{ci.lvl} defines the (outer) probability for the
@@ -146,7 +181,7 @@
 #' @param se Either a logical, and if \code{TRUE}, error bars indicate standard
 #'   errors, not confidence intervals. Or a character vector with a specification
 #'   of the covariance matrix to compute robust standard errors (see argument
-#'   \code{vcov} of \code{link[sjstats]{robust}} for valid values; robust standard
+#'   \code{vcov} of \code{\link[sjstats]{robust}} for valid values; robust standard
 #'   errors are only supported for models that work with \code{\link[lmtest]{coeftest}}).
 #'   \code{se} overrides \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl}
 #'   and \code{transform} will be ignored. Currently, \code{se} only applies
@@ -162,6 +197,8 @@
 #'   raw data points.
 #' @param show.legend For \emph{Marginal Effects} plots, shows or hides the
 #'   legend.
+#' @param show.zeroinf Logical, if \code{TRUE}, shows the zero-inflation part of
+#'   hurdle- or zero-inflated models.
 #' @param value.offset Numeric, offset for text labels to adjust their position
 #'   relative to the dots or lines.
 #' @param dot.size Numeric, size of the dots that indicate the point estimates.
@@ -176,7 +213,7 @@
 #'     \item If \code{colors} is any valid color brewer palette name, the related palette will be used. Use \code{\link[RColorBrewer]{display.brewer.all}} to view all available palette names.
 #'     \item If \pkg{wesanderson} is installed, you may also specify a name of a palette from that package.
 #'     \item If \pkg{viridis} is installed, use \code{colors = "v"} to get the viridis color palette.
-#'     \item There are some pre-defined color palettes in this package: \code{"aqua", "warm", "dust", "blambus", "simply", "us"}.
+#'     \item There are some pre-defined color palettes in this package, see \code{\link{sjPlot-themes}} for details.
 #'     \item Else specify own color values or names as vector (e.g. \code{colors = "#00ff00"} or \code{colors = c("firebrick", "blue")}).
 #'   }
 #' @param grid Logical, if \code{TRUE}, multiple plots are plotted as grid
@@ -187,12 +224,25 @@
 #'   or axis labels are displayed in one line and when a line break is inserted.
 #' @param case Desired target case. Labels will automatically converted into the
 #'   specified character case. See \code{\link[snakecase]{to_any_case}} for more
-#'   details on this argument.
+#'   details on this argument. By default, if \code{case} is not specified,
+#'   it will be set to \code{"parsed"}, unless \code{prefix.labels} is not
+#'   \code{"none"}. If \code{prefix.labels} is either \code{"label"} (or
+#'   \code{"l"}) or \code{"varname"} (or \code{"v"}) and \code{case} is not
+#'   specified, it will be set to \code{NULL} - this is a more convenient
+#'   default when prefixing labels.
 #' @param auto.label Logical, if \code{TRUE} (the default), plot-labels are
 #'   based on value and variable labels, if the data is labelled. See
 #'   \code{\link[sjlabelled]{get_label}} and
 #'   \code{\link[sjlabelled]{get_term_labels}} for details. If \code{FALSE},
 #'   original variable names and value labels (factor levels) are used.
+#' @param prefix.labels Indicates whether the value labels of categorical variables
+#'   should be prefixed, e.g. with the variable name or variable label. See
+#'   argument \code{prefix} in \code{\link[sjlabelled]{get_term_labels}} for
+#'   details.
+#' @param jitter Numeric, between 0 and 1. If \code{show.data = TRUE}, you can
+#'   add a small amount of random variation to the location of each data point.
+#'   \code{jitter} then indicates the width, i.e. how much of a bin's width
+#'   will be occupied by the jittered values.
 #' @param digits Numeric, amount of digits after decimal point when rounding
 #'   estimates or values.
 #' @param value.size Numeric, indicates the size of value labels. Can be used
@@ -203,7 +253,7 @@
 #' @param bpe For \strong{Stan}-models (fitted with the \pkg{rstanarm}- or
 #'   \pkg{brms}-package), the Bayesian point estimate is, by default, the median
 #'   of the posterior distribution. Use \code{bpe} to define other functions to
-#'   calculate the Bayesion point estimate. \code{bpe} needs to be a character
+#'   calculate the Bayesian point estimate. \code{bpe} needs to be a character
 #'   naming the specific function, which is passed to the \code{fun}-argument in
 #'   \code{\link[sjstats]{typical_value}}. So, \code{bpe = "mean"} would
 #'   calculate the mean value of the posterior distribution.
@@ -211,6 +261,9 @@
 #'   \pkg{brms}-package), the Bayesian point estimate is indicated as a small,
 #'   vertical line by default. Use \code{bpe.style = "dot"} to plot a dot
 #'   instead of a line for the point estimate.
+#' @param bpe.color Character vector, indicating the color of the Bayesian
+#'   point estimate. Setting \code{bpe.color = NULL} will inherit the color
+#'   from the mapped aesthetic to match it with the geom's color.
 #' @param ... Other arguments, passed down to various functions. Here is a list
 #'   of supported arguments and their description in detail.
 #'   \describe{
@@ -225,12 +278,16 @@
 #'     }
 #'     \item{\code{size.inner}}{For \strong{Stan}-models and \emph{Coefficients}
 #'       plot-types, you can specify the width of the bar for the inner
-#'       probabilities. Default is \code{0.1}.
+#'       probabilities. Default is \code{0.1}. Setting \code{size.inner = 0}
+#'       removes the inner probability regions.
 #'     }
-#'     \item{\code{width}, \code{alpha} and \code{scale}}{Passed down to
-#'       \code{geom_errorbar()} or \code{geom_density_ridges()}, for forest or
-#'       diagnostic plots; or passed down to \code{\link[ggeffects]{plot.ggeffects}}
-#'       for \emph{Marginal Effects} plots.
+#'     \item{\code{width}, \code{alpha}, and \code{scale}}{Passed
+#'       down to \code{geom_errorbar()} or \code{geom_density_ridges()}, for
+#'       forest or diagnostic plots.
+#'     }
+#'     \item{\code{width}, \code{alpha}, \code{dot.alpha}, \code{dodge} and \code{log.y}}{Passed
+#'       down to \code{\link[ggeffects]{plot.ggeffects}} for \emph{Marginal Effects}
+#'       plots.
 #'     }
 #'     \item{\code{show.loess}}{Logical, for diagnostic plot-types \code{"slope"}
 #'       and \code{"resid"}, adds (or hides) a loess-smoothed line to the plot.
@@ -311,6 +368,10 @@
 #' # grouped coefficients
 #' plot_model(m, group.terms = c(1, 2, 3, 3, 3, 4, 4))
 #'
+#' # keep only selected terms in the model: pos_v_4, the
+#' # levels 3 and 4 of factor e42dep and levels 2 and 3 for c172code
+#' plot_model(m, terms = c("pos_v_4", "e42dep [3,4]", "c172code [2,3]"))
+#'
 #' # multiple plots, as returned from "diagnostic"-plot type,
 #' # can be arranged with 'plot_grid()'
 #' \dontrun{
@@ -351,7 +412,7 @@
 #'   plot_model(m, bpe.style = "dot")
 #' }}
 #'
-#' @importFrom sjstats pred_vars std_beta p_value
+#' @importFrom sjstats pred_vars std_beta p_value model_family
 #' @importFrom sjmisc word_wrap str_contains
 #' @importFrom sjlabelled get_dv_labels get_term_labels
 #' @importFrom dplyr if_else n_distinct
@@ -375,6 +436,7 @@ plot_model <- function(model,
                        title = NULL,
                        axis.title = NULL,
                        axis.labels = NULL,
+                       legend.title = NULL,
                        wrap.title = 50,
                        wrap.labels = 25,
                        axis.lim = NULL,
@@ -387,31 +449,45 @@ plot_model <- function(model,
                        show.p = TRUE,
                        show.data = FALSE,
                        show.legend = TRUE,
+                       show.zeroinf = TRUE,
                        value.offset = NULL,
                        value.size,
+                       jitter = NULL,
                        digits = 2,
                        dot.size = NULL,
                        line.size = NULL,
                        vline.color = NULL,
                        grid,
-                       case = "parsed",
+                       case,
                        auto.label = TRUE,
+                       prefix.labels = c("none", "varname", "label"),
                        bpe = "median",
                        bpe.style = "line",
+                       bpe.color = "white",
                        ...
                        ) {
 
   type <- match.arg(type)
   pred.type <- match.arg(pred.type)
   mdrt.values <- match.arg(mdrt.values)
+  prefix.labels <- match.arg(prefix.labels)
 
 
+  # if we prefix labels, use different default for case conversion,
+  # else the separating white spaces after colon are removed.
+  if (missing(case)) {
+    if (prefix.labels == "none")
+      case <- "parsed"
+    else
+      case <- NULL
+  }
+
   # check se-argument
   se <- check_se_argument(se = se, type = type)
 
 
   # get info on model family
-  fam.info <- get_glm_family(model)
+  fam.info <- sjstats::model_family(model)
 
 
   # check whether estimates should be transformed or not
@@ -432,15 +508,15 @@ plot_model <- function(model,
   if (type %in% c("est", "std", "std2") && isTRUE(auto.label)) {
 
     # get labels of dependent variables, and wrap them if too long
-    if (is.null(title)) title <- sjlabelled::get_dv_labels(model, case = case, ...)
+    if (is.null(title)) title <- sjlabelled::get_dv_labels(model, case = case, multi.resp = fam.info$is_multivariate, ...)
     title <- sjmisc::word_wrap(title, wrap = wrap.title)
 
     # labels for axis with term names
-    if (is.null(axis.labels)) axis.labels <- sjlabelled::get_term_labels(model, case = case, ...)
+    if (is.null(axis.labels)) axis.labels <- sjlabelled::get_term_labels(model, case = case, prefix = prefix.labels, ...)
     axis.labels <- sjmisc::word_wrap(axis.labels, wrap = wrap.labels)
 
     # title for axis with estimate values
-    if (is.null(axis.title)) axis.title <- sjmisc::word_wrap(get_estimate_axis_title(model, axis.title, type, transform), wrap = wrap.title)
+    if (is.null(axis.title)) axis.title <- sjmisc::word_wrap(estimate_axis_title(model, axis.title, type, transform), wrap = wrap.title)
     axis.title <- sjmisc::word_wrap(axis.title, wrap = wrap.labels)
 
   }
@@ -509,7 +585,9 @@ plot_model <- function(model,
       value.size = value.size,
       bpe = bpe,
       bpe.style = bpe.style,
+      bpe.color = bpe.color,
       facets = grid,
+      show.zeroinf = show.zeroinf,
       ...
     )
 
@@ -537,6 +615,7 @@ plot_model <- function(model,
       line.size = line.size,
       vline.color = vline.color,
       value.size = value.size,
+      bpe.color = bpe.color,
       ...
     )
 
@@ -552,9 +631,11 @@ plot_model <- function(model,
       pred.type = pred.type,
       facets = grid,
       show.data = show.data,
+      jitter = jitter,
       geom.colors = colors,
       axis.title = axis.title,
       title = title,
+      legend.title = legend.title,
       axis.lim = axis.lim,
       case = case,
       show.legend = show.legend,
@@ -572,9 +653,11 @@ plot_model <- function(model,
       pred.type = pred.type,
       facets = grid,
       show.data = show.data,
+      jitter = jitter,
       geom.colors = colors,
       axis.title = axis.title,
       title = title,
+      legend.title = legend.title,
       axis.lim = axis.lim,
       case = case,
       show.legend = show.legend,
@@ -594,6 +677,7 @@ plot_model <- function(model,
       colors = colors,
       title = title,
       show.data = show.data,
+      jitter = jitter,
       facets = grid,
       axis.title = axis.title,
       case = case,
@@ -610,6 +694,7 @@ plot_model <- function(model,
       p <- plot_diag_stan(
         model = model,
         geom.colors = colors,
+        axis.lim = axis.lim,
         facets = grid,
         ...
       )
