@@ -6,13 +6,16 @@ plot_type_eff <- function(type,
                           pred.type,
                           facets,
                           show.data,
+                          jitter,
                           geom.colors,
                           axis.title,
                           title,
+                          legend.title,
                           axis.lim,
                           case,
                           show.legend,
                           ...) {
+
   if (type == "pred") {
     dat <- ggeffects::ggpredict(
       model = model,
@@ -31,8 +34,22 @@ plot_type_eff <- function(type,
     )
   }
 
+  # evaluate dots-arguments
+  alpha <- .15
+  dodge <- .1
+  dot.alpha <- .5
+  log.y <- FALSE
+
+  add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
+  if ("alpha" %in% names(add.args)) alpha <- eval(add.args[["alpha"]])
+  if ("dodge" %in% names(add.args)) dodge <- eval(add.args[["dodge"]])
+  if ("dot.alpha" %in% names(add.args)) dot.alpha <- eval(add.args[["dot.alpha"]])
+  if ("log.y" %in% names(add.args)) log.y <- eval(add.args[["log.y"]])
+
+
   # select color palette
-  geom.colors <- col_check2(geom.colors, dplyr::n_distinct(dat$group))
+  if (geom.colors[1] != "bw")
+    geom.colors <- col_check2(geom.colors, dplyr::n_distinct(dat$group))
 
   p <- graphics::plot(
     dat,
@@ -41,16 +58,19 @@ plot_type_eff <- function(type,
     rawdata = show.data,
     colors = geom.colors,
     use.theme = FALSE,
+    jitter = jitter,
     case = case,
     show.legend = show.legend,
-    ...
+    dot.alpha = dot.alpha,
+    alpha = alpha,
+    dodge = dodge,
+    log.y = log.y
   )
 
   # set axis and plot titles
   if (!is.null(axis.title)) {
     if (length(axis.title) > 1) {
-      p <- p + labs(x = axis.title[1],
-                    y = axis.title[2])
+      p <- p + labs(x = axis.title[1], y = axis.title[2])
     } else {
       p <- p + labs(y = axis.title)
     }
@@ -60,10 +80,14 @@ plot_type_eff <- function(type,
   if (!is.null(title))
     p <- p + ggtitle(title)
 
+  # set axis and plot titles
+  if (!is.null(legend.title))
+    p <- p + labs(colour = legend.title)
+
   # set axis limits
   if (!is.null(axis.lim)) {
     if (is.list(axis.lim))
-      p <- p + xlim(axis.lim[[1]]) + + ylim(axis.lim[[2]])
+      p <- p + xlim(axis.lim[[1]]) + ylim(axis.lim[[2]])
     else
       p <- p + ylim(axis.lim)
   }
