@@ -26,12 +26,41 @@ plot_type_ranef <- function(model,
                             line.size,
                             vline.color,
                             value.size,
+                            bpe.color,
                             ...) {
 
+  if (inherits(model, "clmm")) {
+    se <- FALSE
+    ci.lvl <- NA
+  }
+
   # get tidy output of summary ----
 
-  rand.ef <- lme4::ranef(model)
-  rand.se <- arm::se.ranef(model)
+  if (inherits(model, "glmmTMB"))
+    rand.ef <- glmmTMB::ranef(model)[[1]]
+  else
+    rand.ef <- lme4::ranef(model)
+
+
+  if (inherits(model, "clmm"))
+    rand.se <- NULL
+  else if (inherits(model, "glmmTMB")) {
+    if (requireNamespace("TMB", quietly = TRUE)) {
+      s1 <- TMB::sdreport(model$obj, getJointPrecision = TRUE)
+      s2 <- sqrt(s1$diag.cov.random)
+      rand.se <- purrr::map(rand.ef, function(.x) {
+        cnt <- nrow(.x) * ncol(.x)
+        s3 <- s2[1:cnt]
+        s2 <- s2[-(1:cnt)]
+        as.data.frame(matrix(sqrt(s3), ncol = ncol(.x), byrow = TRUE))
+      })
+    } else {
+      se <- FALSE
+      ci.lvl <- NA
+      rand.se <- NULL
+    }
+  } else
+    rand.se <- arm::se.ranef(model)
 
 
   # get some initial values
@@ -120,7 +149,7 @@ plot_type_ranef <- function(model,
   for (lcnt in loops) {
 
     mydf.ef <- as.data.frame(rand.ef[[lcnt]])
-    se.fit <- rand.se[[lcnt]]
+    if (!sjmisc::is_empty(rand.se)) se.fit <- rand.se[[lcnt]]
 
     grp.names <- colnames(mydf.ef)
     grp.names[2] <- paste(ran.names[lcnt], grp.names[2])
@@ -285,6 +314,8 @@ plot_type_ranef <- function(model,
           geom.colors = geom.colors,
           vline.color = vline.color,
           value.size = value.size,
+          facets = facets,
+          bpe.color = bpe.color,
           ...
         )
       }
