@@ -76,7 +76,7 @@
 #' # fit sample model
 #' fit <- lm(tot_sc_e ~ c12hour + e17age + e42dep, data = efc)
 #' # inspect relationship between predictors and response
-#' sjp.lm(fit, type = "slope", show.loess = TRUE, show.scatter = FALSE)
+#' plot_model(fit, type = "slope")
 #' # "e17age" does not seem to be linear correlated to response
 #' # try to find appropiate polynomial. Grey line (loess smoothed)
 #' # indicates best fit. Looks like x^4 has the best fit,
@@ -88,7 +88,7 @@
 #' fit <- lm(tot_sc_e ~ c12hour + e42dep + e17age + I(e17age^2) + I(e17age^3),
 #'           data = efc)
 #' # plot marginal effects of polynomial term
-#' sjp.lm(fit, type = "poly", poly.term = "e17age")}
+#' plot_model(fit, type = "pred", terms = "e17age")}
 #'
 #' @import ggplot2
 #' @importFrom scales grey_pal brewer_pal
@@ -164,7 +164,7 @@ sjp.poly <- function(x,
   # --------------------------------------------
   # get cutpoints for loess curve
   # --------------------------------------------
-  cutpoints <- get_loess_cutpoints(na.omit(data.frame(x = poly.term, y = resp)))
+  cutpoints <- get_loess_cutpoints(stats::na.omit(data.frame(x = poly.term, y = resp)))
   # --------------------------------------------
   # if user wants to plot multiple curves for
   # polynomials, create data frame for each curve here
