@@ -52,121 +52,6 @@
 #'       errors of transformed regression parameters (see \code{\link[sjstats]{se}}).
 #'       If \code{exp.coef = FALSE} and log-Odds Ratios are reported, the standard
 #'       errors are untransformed.
-#'       \cr \cr Futhermore, see 'Notes' in \code{\link{sjt.frq}}.
-#'
-#' @details See 'Details' in \code{\link{sjt.frq}}.
-#'
-#' @examples
-#' # prepare dummy variables for binary logistic regression
-#' swiss$y1 <- ifelse(swiss$Fertility < median(swiss$Fertility), 0, 1)
-#' swiss$y2 <- ifelse(swiss$Infant.Mortality < median(swiss$Infant.Mortality), 0, 1)
-#' swiss$y3 <- ifelse(swiss$Agriculture < median(swiss$Agriculture), 0, 1)
-#'
-#' # Now fit the models. Note that both models share the same predictors
-#' # and only differ in their dependent variable (y1, y2 and y3)
-#' fitOR1 <- glm(y1 ~ Education + Examination + Catholic, data = swiss,
-#'               family = binomial(link = "logit"))
-#' fitOR2 <- glm(y2 ~ Education + Examination + Catholic, data = swiss,
-#'               family = binomial(link = "logit"))
-#' fitOR3 <- glm(y3 ~ Education + Examination + Catholic, data = swiss,
-#'               family = binomial(link = "logit"))
-#'
-#' \dontrun{
-#' # open HTML-table in RStudio Viewer Pane or web browser
-#' sjt.glm(fitOR1, fitOR2,
-#'         depvar.labels = c("Fertility", "Infant Mortality"),
-#'         pred.labels = c("Education", "Examination", "Catholic"),
-#'         ci.hyphen = " to ")
-#'
-#' # open HTML-table in RStudio Viewer Pane or web browser,
-#' # integrate CI in OR column
-#' sjt.glm(fitOR1, fitOR2, fitOR3,
-#'         pred.labels = c("Education", "Examination", "Catholic"),
-#'         separate.ci.col = FALSE)
-#'
-#' # open HTML-table in RStudio Viewer Pane or web browser,
-#' # indicating p-values as numbers and printing CI in a separate column
-#' sjt.glm(fitOR1, fitOR2, fitOR3,
-#'         depvar.labels = c("Fertility", "Infant Mortality", "Agriculture"),
-#'         pred.labels = c("Education", "Examination", "Catholic"))
-#'
-#' # --------------------------------------------
-#' # User defined style sheet
-#' # --------------------------------------------
-#' sjt.glm(fitOR1, fitOR2, fitOR3,
-#'         depvar.labels = c("Fertility", "Infant Mortality", "Agriculture"),
-#'         pred.labels = c("Education", "Examination", "Catholic"),
-#'         show.header = TRUE,
-#'         CSS = list(css.table = "border: 2px solid;",
-#'                    css.tdata = "border: 1px solid;",
-#'                    css.depvarhead = "color:#003399;"))
-#'
-#' # --------------------------------------------
-#' # Compare models with different link functions,
-#' # but same predictors and response
-#' # --------------------------------------------
-#' library(sjmisc)
-#' # load efc sample data
-#' data(efc)
-#' # dichtomozize service usage by "service usage yes/no"
-#' efc$services <- sjmisc::dicho(efc$tot_sc_e, dich.by = 0, as.num = TRUE)
-#' # fit 3 models with different link-functions
-#' fit1 <- glm(services ~ neg_c_7 + c161sex + e42dep,
-#'             data = efc, family = binomial(link = "logit"))
-#' fit2 <- glm(services ~ neg_c_7 + c161sex + e42dep,
-#'             data = efc, family = binomial(link = "probit"))
-#' fit3 <- glm(services ~ neg_c_7 + c161sex + e42dep,
-#'             data = efc, family = poisson(link = "log"))
-#'
-#' # compare models
-#' sjt.glm(fit1, fit2, fit3, string.est = "Estimate",
-#'         show.aic = TRUE, show.family = TRUE)
-#'
-#' # --------------------------------------------
-#' # Change style of p-values and CI-appearance
-#' # --------------------------------------------
-#' # open HTML-table in RStudio Viewer Pane or web browser,
-#' # table indicating p-values as stars
-#' sjt.glm(fit1, fit2, fit3, p.numeric = FALSE,
-#'         show.aic = TRUE, show.family = TRUE)
-#'
-#' # open HTML-table in RStudio Viewer Pane or web browser,
-#' # indicating p-values as stars and integrate CI in OR column
-#' sjt.glm(fit1, fit2, fit3, p.numeric = FALSE, separate.ci.col = FALSE,
-#'         show.aic = TRUE, show.family = TRUE, show.r2 = TRUE)
-#'
-#' # ----------------------------------
-#' # automatic grouping of predictors
-#' # ----------------------------------
-#' library(sjmisc)
-#' # load efc sample data
-#' data(efc)
-#' # dichtomozize service usage by "service usage yes/no"
-#' efc$services <- sjmisc::dicho(efc$tot_sc_e, dich.by = 0, as.num = TRUE)
-#' # make dependency categorical
-#' efc$e42dep <- to_factor(efc$e42dep)
-#' # fit model with "grouped" predictor
-#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep, data = efc)
-#'
-#' # automatic grouping of categorical predictors
-#' sjt.glm(fit)
-#'
-#' # ----------------------------------
-#' # compare models with different predictors
-#' # ----------------------------------
-#' fit2 <- glm(services ~ neg_c_7 + c161sex + e42dep + c12hour, data = efc)
-#' fit3 <- glm(services ~ neg_c_7 + c161sex + e42dep + c12hour + c172code,
-#'             data = efc)
-#'
-#' # print models with different predictors
-#' sjt.glm(fit, fit2, fit3)
-#'
-#' efc$c172code <- to_factor(efc$c172code)
-#' fit2 <- glm(services ~ neg_c_7 + c161sex + c12hour, data = efc)
-#' fit3 <- glm(services ~ neg_c_7 + c161sex + c172code, data = efc)
-#'
-#' # print models with different predictors
-#' sjt.glm(fit, fit2, fit3, group.pred = FALSE)}
 #'
 #' @importFrom dplyr full_join slice mutate if_else
 #' @importFrom stats nobs AIC confint coef logLik family deviance
@@ -231,6 +116,13 @@ sjt.glm <- function(...,
     p_zero <- ""
   else
     p_zero <- "0"
+
+  if (stats::runif(1) < .35)
+    message("`sjt.lm()` and `sjt.lmer()` will become deprecated in the future. Please use `tab_model()` instead.")
+
+  ## TODO activate in future update
+  # .Deprecated("tab_model")
+
   # check hyphen for ci-range
   if (is.null(ci.hyphen)) ci.hyphen <- "&nbsp;&ndash;&nbsp;"
   # replace space with protected space in ci-hyphen
@@ -449,7 +341,7 @@ sjt.glm <- function(...,
   # select correct column heading, depending on model family and link function
   if (is.null(string.est)) {
     # get family
-    fitfam <- get_glm_family(input_list[[1]])
+    fitfam <- sjstats::model_family(input_list[[1]])
     # check if we have a binomial model
     if (fitfam$is_bin) {
       # here we gor for logistic regression
@@ -602,7 +494,7 @@ sjt.glm <- function(...,
     page.content <- paste(page.content, "\n  </tr>\n")
   }
   # -------------------------------------
-  # 1. table part: "Fixed parts" - only used
+  # 1. table part: "Fixed Effects" - only used
   # for linear mixed models
   # -------------------------------------
   if (lmerob) {
@@ -1152,7 +1044,7 @@ sjt.glm <- function(...,
 #' @note Computation of p-values (if necessary) is based on normal-distribution
 #'         assumption, treating the t-statistics as Wald z-statistics.
 #'         \cr \cr
-#'         The variance components of the random parts (see \code{show.re.var}) are
+#'         The variance components of the random effects (see \code{show.re.var}) are
 #'         denoted like:
 #'         \itemize{
 #'          \item between-group-variance: tau-zero-zero
@@ -1163,50 +1055,6 @@ sjt.glm <- function(...,
 #'       \code{summary()}-method. Rather, \code{sjt.glmer()} uses adjustments
 #'       according to the delta method for approximating standard errors of
 #'       transformed regression parameters (see \code{\link[sjstats]{se}}).
-#'       \cr \cr Futhermore, see 'Notes' in \code{\link{sjt.frq}}.
-#'
-#' @details See 'Details' in \code{\link{sjt.frq}}.
-#'
-#' @examples
-#' \dontrun{
-#' library(lme4)
-#' library(sjmisc)
-#' data(efc)
-#'
-#' # create binary response
-#' efc$hi_qol <- dicho(efc$quol_5)
-#' # prepare group variable
-#' efc$grp = as.factor(efc$e15relat)
-#' levels(x = efc$grp) <- get_labels(efc$e15relat)
-#' # data frame for fitted model
-#' mydf <- data.frame(hi_qol = to_factor(efc$hi_qol),
-#'                    sex = to_factor(efc$c161sex),
-#'                    c12hour = efc$c12hour,
-#'                    neg_c_7 = efc$neg_c_7,
-#'                    education = to_factor(efc$c172code),
-#'                    grp = efc$grp)
-#'
-#' # fit glmer
-#' fit1 <- glmer(hi_qol ~ sex + c12hour + neg_c_7 + (1|grp),
-#'               data = mydf, family = binomial("logit"))
-#' fit2 <- glmer(hi_qol ~ sex + c12hour + neg_c_7 + education + (1|grp),
-#'               data = mydf, family = binomial("logit"))
-#'
-#' # print summary table
-#' sjt.glmer(fit1, fit2, ci.hyphen = " to ")
-#'
-#' # print summary table, using different table layout
-#' sjt.glmer(fit1, fit2, show.aic = TRUE, show.ci = FALSE,
-#'           show.se = TRUE, p.numeric = FALSE)
-#'
-#' # print summary table
-#' sjt.glmer(fit1, fit2, pred.labels = c("Elder's gender (female)",
-#'             "Hours of care per week", "Negative Impact",
-#'             "Educational level (mid)", "Educational level (high)"))
-#'
-#' # use vector names as predictor labels
-#' sjt.glmer(fit1, fit2, pred.labels = "")}
-#'
 #'
 #' @export
 sjt.glmer <- function(...,
